=================
 What is gevent?
=================

.. include:: _about.rst

:ref:`Continue reading <installation>` »

If you like gevent, :doc:`donate <sfc>` to support the development.

What are others saying?
=======================


Mailing List
------------

.. raw:: html

   <iframe id="forum_embed"
         src="javascript:void(0)"
         scrolling="no"
         frameborder="0"
         width="100%"
         height="500">
   </iframe>

   <script type="text/javascript">
         document.getElementById("forum_embed").src = "https://groups.google.com/forum/embed/?place=forum/gevent"
             + "&showsearch=false&showtabs=false&hideforumtitle=true&showpopout=true&parenturl=" + encodeURIComponent(window.location.href);
   </script>

.. _coroutine: https://en.wikipedia.org/wiki/Coroutine
.. _Python: http://python.org
.. _greenlet: https://greenlet.readthedocs.io
.. _libev: http://software.schmorp.de/pkg/libev.html
.. _libuv: http://libuv.org
